--==========================================================
-- Design units : BlackJack_BB(Entity, Architecture, Configuration)
--
-- File name    : BlackJack_BB.vhd
--
-- Purpose      : BlackBox for BJ dealer
--
-- Limitations  : -
--
-- Library      : IEEE, work
--
-- Dependencies : BlackJack_CTRL, BlackJack_DataPath
--
-- Author       : Claus-Juergen Thomas, REFT
--
-- Simulator    : Synopsys V3.2a on SUN SPARCstation 10
--
-----------------------------------------------------------
-- Revision list
-- Version Author Date           Changes
--
--  v1.0   cjt    04.07.1996     new
--=========================================================

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE work.BlackJack_Pack.all;

ENTITY BlackJack_BB IS
PORT(card_value : IN std_logic_vector(3 DOWNTO 0);
     card_ready : IN std_logic;
     clk        : IN std_logic;
     reset      : IN std_logic;
     stand_ind  : OUT std_logic;
     broke_ind  : OUT std_logic;
     hit_ind    : OUT std_logic;
     Score      : OUT std_logic_vector(4 DOWNTO 0));
END BlackJack_BB;

--============================ARCHITECTURE==================

ARCHITECTURE Structure OF BlackJack_BB IS

SIGNAL Card_rdy_s,Card_rdy_d,Acecard,ScoreGT16,
       ScoreGT21,Stand,Broke,Ace11flag,
       S_Get,S_Add,S_Use,S_Test : std_logic;
SIGNAL Set_Stand, Clr_Stand,Set_Broke,Clr_Broke,
       Set_Ace11flag,Clr_Ace11flag,Ld_Score,Clr_Score,
       Adder_S0,Adder_S1,Hit: std_logic;

BEGIN

CTRL: BlackJack_CTRL
  PORT MAP(Card_rdy_s,Card_rdy_d,Acecard,ScoreGT16,
           ScoreGT21,Stand,Broke,Ace11flag,Reset,Clk,
           Set_Stand,Clr_Stand,Set_Broke,Clr_Broke,
           Set_Ace11flag,Clr_Ace11flag,Ld_Score,Clr_Score,
           Adder_S0,Adder_S1,Hit);

DP : BlackJack_DataPath
  PORT MAP(Card_value,Card_ready,Set_Ace11flag,Clr_Ace11flag,
           Ld_Score,Clr_Score,Set_Stand,Clr_Stand,
           Set_Broke,Clr_Broke,Adder_S0,Adder_S1,
           Reset,Clk,Card_rdy_s,Card_rdy_d,Acecard,
           ScoreGT16,ScoreGT21,Stand,Broke,Ace11flag,Score);

stand_ind <= stand;
broke_ind <= broke;
hit_ind <= hit;
     
END Structure;

--============================CONFIGURATION=================

CONFIGURATION BlackJack_BB_Config OF BlackJack_BB IS

  FOR Structure

    FOR CTRL : BlackJack_CTRL
      USE ENTITY work.BlackJack_Ctrl(Structure);
    END FOR;

    FOR DP : BlackJack_DataPath
      USE ENTITY work.BlackJack_DataPath(Structure);
    END FOR;

  END FOR;

END BlackJack_BB_Config;

